@@ -1,28 +1,3 @@
-
-#.onAttach <- function(libname, pkgname) {
-#
-#    sup <- file.path(libname, pkgname, "startup.txt")
-#    if (file.exists(sup) || !interactive()) return(TRUE)
-#    if (!suppressWarnings(file.create(sup))) return(TRUE)
-#    file.remove(sup)
-#    version <- packageDescription(pkg = pkgname)$Version
-#    txt <- c("\n",
-#             paste("	Welcome to ", sQuote("mboost"),
-#                   " version ", version, "!", sep = ""),
-#             "\n",
-#             "The user-interface changed in some places.",
-#             paste("Most important, subsetting an", sQuote("mboost"),
-#                   "object modifies this object now."),
-#             "Please read the NEWS file, consult the documentation and have fun!",
-#             "\n",
-#             "Would you like to see this message on startup again?")
-#    packageStartupMessage(txt)
-#    choice <- menu(c("Please, no!", "Yes, please!"))
-#    if (choice == 2) return(TRUE)
-#    file.create(sup)
-#    return(TRUE)
-#}
-
 .onAttach <- function(libname, pkgname) {
 
     ## get package version
@@ -44,7 +19,9 @@
             mboost_dftraceS = FALSE,  ### df = trace(S) or df = trace(2 S - StS)
             mboost_lambdaMax = 1e+15,### maximum value for lambda as used in df2lambda
             mboost_Xmonotone = FALSE,### don't force monotonicity in %X%
-            mboost_eps = 10e-10)     ### factor for dmat in df2lambda
+            mboost_eps = 10e-10, ### factor for dmat in df2lambda
+            mboost_check_df2lambda = TRUE) ### check if max(abs(X)) > 10 in df2lambda
+                                 ### as this might take a while experts can skip this check
 }
 
 .onUnload <- function(libpath) {
