@@ -74,14 +74,16 @@ cvrisk.mboost <- function (object, folds = cv(model.weights(object)),
     OOBweights[folds > 0] <- 0
     if (all.equal(papply, mclapply) == TRUE) {
         oobrisk <- papply(1:ncol(folds),
-                          function(i) dummyfct(weights = folds[, i],
-                                               oobweights = OOBweights[, i]),
+                          function(i) try(dummyfct(weights = folds[, i],
+                                                   oobweights = OOBweights[, i]),
+                                          silent = TRUE),
                           mc.preschedule = mc.preschedule,
                           ...)
     } else {
         oobrisk <- papply(1:ncol(folds),
                           function(i) try(dummyfct(weights = folds[, i],
-                                                   oobweights = OOBweights[, i])),
+                                                   oobweights = OOBweights[, i]),
+                                          silent = TRUE),
                           ...)
     }
     ## if any errors occured remove results and issue a warning
