@@ -85,8 +85,8 @@ mboost_fit <- function(blg, response, weights = rep(1, NROW(response)),
                tsums[i] <- mean.default(weights * ((sstmp$fitted()) - u)^2,
                                         na.rm = TRUE)
            }
-           if (all(tsums < 0))
-               stop("could not fit base learner in boosting iteration ", m)
+           if (all(is.na(tsums)) || all(tsums < 0))
+               stop("could not fit any base-learner in boosting iteration ", m)
            xselect[m] <<- which.min(tsums)
            return(ss[[xselect[m]]])
         }
@@ -96,6 +96,8 @@ mboost_fit <- function(blg, response, weights = rep(1, NROW(response)),
             bnames <- bl[[1]]$Xnames
             basefit <- function(u, m) {
                 mod <- fit1(y = u)
+                if(all(is.na(coef(mod))))
+                    stop("could not fit any base-learner in boosting iteration ", m)
                 xselect[m] <<- mod$model["xselect"]
                 return(mod)
             }
@@ -103,7 +105,11 @@ mboost_fit <- function(blg, response, weights = rep(1, NROW(response)),
             bnames <- names(bl)
             basefit <- function(u, m) {
                 xselect[m] <<- 1L
-                return(fit1(y = u))
+                mod <- fit1(y = u)
+                if((!is.null(coef(mod)) && all(is.na(coef(mod)))) ||
+                   all(is.na(mean.default(weights * ((mod$fitted()) - u)^2, na.rm = TRUE))))
+                    stop("could not fit base-learner in boosting iteration ", m)
+                return(mod)
             }
         }
     }
@@ -266,7 +272,10 @@ mboost_fit <- function(blg, response, weights = rep(1, NROW(response)),
                 ## was made via the `which' argument
                 ret <- matrix(rowSums(pr), ncol = 1)
                 if (length(offset) != 1 && !is.null(newdata)) {
-                    warning("Offset not used for prediction when ", sQuote("newdata"), " is specified")
+                    warning(sQuote("length(offset) > 1"),
+                            ": User-specified offset is not a scalar, ",
+                            "thus offset not used for prediction when ",
+                            sQuote("newdata"), " is specified")
                 } else {
                     ret <- ret + offset
                 }
@@ -286,7 +295,10 @@ mboost_fit <- function(blg, response, weights = rep(1, NROW(response)),
                 for (i in 1:max(xselect)) pr <- pr + pfun(i, agg = "none")
                 pr <- .Call("R_mcumsum", as(pr, "matrix"), PACKAGE = "mboost")
                 if (length(offset) != 1 && !is.null(newdata)) {
-                    warning("Offset not used for prediction when ", sQuote("newdata"), " is specified")
+                    warning(sQuote("length(offset) > 1"),
+                            ": User-specified offset is not a scalar, ",
+                            "thus offset not used for prediction when ",
+                            sQuote("newdata"), " is specified")
                 } else {
                     pr <- pr + offset
                 }
@@ -427,9 +439,31 @@ mboost_fit <- function(blg, response, weights = rep(1, NROW(response)),
 ### is evaluated as
 ###     y ~ bols3(x1) + baselearner(x2) + btree(x3)
 ### see mboost_fit for the dots
-mboost <- function(formula, data = list(),
+mboost <- function(formula, data = list(), na.action = na.omit,
     baselearner = c("bbs", "bols", "btree", "bss", "bns"), ...) {
 
+
+    ## We need at least variable names to go ahead
+    if (length(formula[[3]]) == 1) {
+        if (as.name(formula[[3]]) == ".") {
+            formula <- as.formula(paste(deparse(formula[[2]]),
+                "~", paste(names(data)[names(data) != all.vars(formula[[2]])],
+                           collapse = "+"), collapse = ""))
+        }
+    }
+
+    if (is.data.frame(data)) {
+        if (!all(complete.cases(data))) {
+            ## drop cases with missing values in any of the specified variables:
+            vars <- all.vars(formula)[all.vars(formula) %in% names(data)]
+            data <- na.action(data[, vars])
+        }
+    } else {
+        if (any(unlist(lapply(data, is.na))))
+            warning(sQuote("data"),
+                    " contains missing values. Results might be affected. Consider removing missing values.")
+    }
+
     if (is.character(baselearner)) {
         baselearner <- match.arg(baselearner)
         bname <- baselearner
@@ -444,14 +478,6 @@ mboost <- function(formula, data = list(),
     }
     stopifnot(is.function(baselearner))
 
-    ### OK, we need at least variable names to go ahead
-    if (length(formula[[3]]) == 1) {
-        if (as.name(formula[[3]]) == ".") {
-            formula <- as.formula(paste(deparse(formula[[2]]),
-                "~", paste(names(data)[names(data) != all.vars(formula[[2]])],
-                           collapse = "+"), collapse = ""))
-        }
-    }
     ### instead of evaluating a model.frame, we evaluate
     ### the expressions on the rhs of formula directly
     "+" <- function(a,b) {
@@ -527,7 +553,8 @@ gamboost <- function(formula, data = list(),
 
 
 ### just one single tree-based baselearner
-blackboost <- function(formula, data = list(),
+blackboost <- function(formula, data = list(), weights = NULL,
+    na.action = na.pass,
     tree_controls = party::ctree_control(teststat = "max",
                                testtype = "Teststatistic",
                                mincriterion = 0,
@@ -537,16 +564,19 @@ blackboost <- function(formula, data = list(),
     ### get the model frame first
     cl <- match.call()
     mf <- match.call(expand.dots = FALSE)
-    m <- match(c("formula", "data", "weights"), names(mf), 0L)
+    m <- match(c("formula", "data", "weights", "na.action"), names(mf), 0L)
     mf <- mf[c(1L, m)]
-    mf$na.action <- na.pass
     mf$drop.unused.levels <- TRUE
     mf[[1L]] <- as.name("model.frame")
     mf <- eval(mf, parent.frame())
     response <- model.response(mf)
+    weights <- model.weights(mf)
+    ## drop outcome
     mf <- mf[,-1, drop = FALSE]
+    ## drop weights
+    mf$"(weights)" <- NULL
     bl <- list(btree(mf, tree_controls = tree_controls))
-    ret <- mboost_fit(bl, response = response, ...)
+    ret <- mboost_fit(bl, response = response, weights = weights, ...)
     ret$call <- cl
     ret$rownames <- rownames(mf)
     class(ret) <- c("blackboost", class(ret))
@@ -560,15 +590,25 @@ glmboost.formula <- function(formula, data = list(), weights = NULL,
                              na.action = na.pass, contrasts.arg = NULL,
                              center = TRUE, control = boost_control(), ...) {
 
+    ## We need at least variable names to go ahead
+    if (length(formula[[3]]) == 1) {
+        if (as.name(formula[[3]]) == ".") {
+            formula <- as.formula(paste(deparse(formula[[2]]),
+                "~", paste(names(data)[names(data) != all.vars(formula[[2]])],
+                           collapse = "+"), collapse = ""))
+        }
+    }
+
     ### get the model frame first
     cl <- match.call()
     mf <- match.call(expand.dots = FALSE)
-    m <- match(c("formula", "data", "weights"), names(mf), 0L)
+    m <- match(c("formula", "data", "weights", "na.action"), names(mf), 0L)
     mf <- mf[c(1L, m)]
-    mf$na.action <- na.action
     mf$drop.unused.levels <- TRUE
+    mf$data <- data ## use cc data
     mf[[1L]] <- as.name("model.frame")
     mf <- eval(mf, parent.frame())
+
     ### center argument moved to this function
     if (!control$center) {
         center <- FALSE
@@ -589,7 +629,7 @@ glmboost.formula <- function(formula, data = list(), weights = NULL,
     ### this function will be used for predictions later
     newX <- function(newdata) {
         mf <- model.frame(delete.response(attr(mf, "terms")),
-                          data = newdata, na.action = na.pass)
+                          data = newdata, na.action = na.action)
         X <- model.matrix(delete.response(attr(mf, "terms")),
                           data = mf, contrasts.arg = contrasts.arg)
         scale(X, center = cm, scale = FALSE)
@@ -655,7 +695,8 @@ glmboost.formula <- function(formula, data = list(), weights = NULL,
     return(ret)
 }
 
-glmboost.matrix <- function(x, y, center = TRUE,
+glmboost.matrix <- function(x, y, center = TRUE, weights = NULL,
+                            na.action = na.pass,
                             control = boost_control(), ...) {
 
     X <- x
@@ -664,6 +705,15 @@ glmboost.matrix <- function(x, y, center = TRUE,
              " do not match")
     if (is.null(colnames(X)))
         colnames(X) <- paste("V", 1:ncol(X), sep = "")
+
+    ## drop cases with missing values in any of the specified variables:
+    if (any(!Complete.cases(cbind(X, y)))) {
+        X <- na.action(X)
+        if (!is.null(removed <- attr(X, "na.action"))) {
+            y <- y[-removed]
+        }
+    }
+
     if (!control$center) {
         center <- FALSE
         warning("boost_control(center = FALSE) is deprecated, use glmboost(..., center = FALSE)")
